@@ -795,6 +795,20 @@ class WeBarometerSensor:
       value=weSerial.read(count)
       if len(value) == count:
         return round((value[0]|value[1]<<8|value[2]<<16|value[3]|24)/100,2)
+
+# Compass Sensor
+class WeCompassSensor:
+  """docstring for WeCompassSensor"""
+  def __init__(self, port):
+    self.port = port  # port:PORT_*
+  
+  def getValue(self, index):   # index: 0->X, 1->Y, 2->Z
+    cmd='M51 '+str(self.port)+' '+str(index)+'\r\n'
+    weSerial.write(bytearray(cmd.encode('utf-8')))
+    time.sleep(0.05)
+    value=weSerial.readline()
+    return eval(value)
+
 # Gyro Sensor
 class WeGyroSensor:
   """docstring for GyroSensor"""
@@ -808,19 +822,6 @@ class WeGyroSensor:
     value=weSerial.readline()
     return eval(value)
 
-# Compass Sensor
-class WeCompassSensor:
-  """docstring for WeCompassSensor"""
-  def __init__(self, port):
-    self.port = port  # port:PORT_*
-  
-  def getValue(self, index):   # index: 0->X, 1->Y, 2->Z
-    cmd='M61 '+str(self.port)+' '+str(index)+'\r\n'
-    weSerial.write(bytearray(cmd.encode('utf-8')))
-    time.sleep(0.05)
-    value=weSerial.readline()
-    return eval(value)
-
 # Adapter Module V2.0
 class WeAdapter:
   """docstring for WeAdapter"""
@@ -828,7 +829,7 @@ class WeAdapter:
     self.port = port  # port:PORT_*
 
   def servo_write(self,slot,angle):  # slot:1~4  angle:0~180
-    cmd='M11 '+str(self.port)+' 2 2 '+str(slot)+' '+str(angle)+'\r\n'
+    cmd='M81 '+str(self.port)+' '+str(slot)+' '+str(angle)+'\r\n'
     weSerial.write(bytearray(cmd.encode('utf-8')))
     time.sleep(0.05)
 
@@ -838,41 +839,32 @@ class WeAdapter:
     red=(aa[0])
     green=(aa[1])
     blue=(aa[2])
-    cmd='M11 '+str(self.port)+' 3 5 '+str(slot)+' '+str(index)+' '+str(red)+' '+str(green)+' '+str(blue)+'\r\n'
+    cmd='M82 '+str(self.port)+' '+str(slot)+' '+str(index)+' '+str(red)+' '+str(green)+' '+str(blue)+'\r\n'
     weSerial.write(bytearray(cmd.encode('utf-8')))
     time.sleep(0.05)
 
   def ds18b20_read(self,slot):
-    cmd='M13 '+str(self.port)+' '+str(0x04+slot-1)+' 2\r\n'
+    cmd='M83 '+str(self.port)+' '+str(slot)+'\r\n'
     weSerial.write(bytearray(cmd.encode('utf-8')))
     time.sleep(0.05)
-    count = weSerial.inWaiting() 
-    if count > 0:
-      value=weSerial.read(count)
-      if len(value) == count:
-        return round((value[1]<<8|value[0])/100.00,2)
-
-  def analog_read(self,slot):
-    cmd='M13 '+str(self.port)+' '+str(0x08+slot-1)+' 2\r\n'
+    value=weSerial.readline()
+    return round(eval(value),2)
+  
+  def digital_write(self,slot,value):  # slot:1~4  value:0/1
+    cmd='M84 '+str(self.port)+' '+str(slot)+' '+str(vaule)+'\r\n'
     weSerial.write(bytearray(cmd.encode('utf-8')))
     time.sleep(0.05)
-    count = weSerial.inWaiting() 
-    if count > 0:
-      value=weSerial.read(count)
-      if len(value) == count:
-        return int(value[0])
 
   def digital_read(self,slot):
-    cmd='M13 '+str(self.port)+' '+str(0x0d+slot-1)+' 1\r\n'
+    cmd='M85 '+str(self.port)+' '+str(slot)+' 1\r\n'
     weSerial.write(bytearray(cmd.encode('utf-8')))
     time.sleep(0.05)
-    count = weSerial.inWaiting() 
-    if count > 0:
-      value=weSerial.read(count)
-      if len(value) == count:
-        return int(value[0])
+    value=weSerial.readline()
+    return eval(value)
 
-  def digital_write(self,slot,value):  # slot:1~4  value:0/1
-    cmd='M11 '+str(self.port)+' 12 2 '+str(slot)+' '+str(vaule)+'\r\n'
+  def analog_read(self,slot):
+    cmd='M86 '+str(self.port)+' '+str(slot)+' 2\r\n'
     weSerial.write(bytearray(cmd.encode('utf-8')))
-    time.sleep(0.05)
\ No newline at end of file
+    time.sleep(0.05)
+    value=weSerial.readline()
+    return eval(value)
\ No newline at end of file
